<?php
/**
 * @package WordPress
 * @subpackage Documentation
 */

if ( ! isset( $content_width ) )
	$content_width = 900;

add_action( 'after_setup_theme', 'documentation_setup' );

if ( ! function_exists( 'documentation_setup' ) ) {
	function documentation_setup() {
		/**
		 * Make Twenty Twelve available for translation.
		 * Translations can be added to the /languages/ directory.
		 * If you're building a theme based on Twenty Twelve, use a find and replace
		 * to change 'documentation' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'documentation', get_template_directory() . '/languages' );
	
		// Add default posts and comments RSS feed links to <head>.
		add_theme_support( 'automatic-feed-links' );
	
		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', __( 'Primary Menu', 'documentation' ) );
	
		// Add support for custom background.
		add_custom_background();
	
		// The default header text color
		define( 'HEADER_TEXTCOLOR', '111' );
	}
}


if ( ! function_exists( 'documentation_widgets_init' ) ) {
	// Register widgetized areas
	function documentation_widgets_init() {
		// Area 1
		register_sidebar( array (
			'name'          => __('Primary Widget Area', 'documentation'),
			'id'            => 'primary-widget-area',
			'description'   => __('The primary widget area is visible on all pages and posts.', 'documentation'),
			'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			'after_widget'  => "</li>",
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
		
		// Area 2
		register_sidebar( array (
			'name'          => __('Secondary Widget Area', 'documentation'),
			'id'            => 'secondary-widget-area', 
			'description'   => __('The secondary widget area down below Primary Widget Area only on pages and posts.' , 'documentation'),
			'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			'after_widget'  => "</li>",
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	} // end theme_widgets_init
	
	add_action( 'widgets_init', 'documentation_widgets_init' );
}


if ( ! function_exists( 'documentation_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own documentation_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Twenty Twelve 1.0
 */
function documentation_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'documentation' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'documentation' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'documentation' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'documentation' ), get_comment_date(), get_comment_time() )
							)
						);
					?>

					<?php edit_comment_link( __( 'Edit', 'documentation' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'documentation' ); ?></em>
					<br />
				<?php endif; ?>
			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'documentation' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif;


if ( ! function_exists( 'documentation_login_headertitle' ) ) {
	function documentation_login_headertitle() {
		
		return get_option('blogname');
	}
	add_filter( 'login_headertitle', 'documentation_login_headertitle' );
	
	function documentation_login_url() {
		
		return home_url();
	}
	add_filter( 'login_headerurl', 'documentation_login_url' );
	
	function documentation_custom_login_logo() {
		?>
		<style type="text/css">
			h1 a {
				background: transparent url('<?php echo home_url(); ?>/favicon.ico') no-repeat 30px center !important;
				text-indent: 0 !important;
				font-size: 13px !important;
				margin: 0 0 0 20px !important;
			}
		</style>
		<?php
	}
	add_action( 'login_head', 'documentation_custom_login_logo' );
}
